Features
********


This section describes all features that are shipped with this package.


Scenario Features
=================

.. note::
    This package does not provide any scenario features

.. autoclass:: balderhub.waveformmonitor.lib.scenario_features.WaveformMonitorFeature
    :members:

Instruments
-----------

.. autoclass:: balderhub.waveformmonitor.lib.scenario_features.WaveformMonitorInstrument
    :members:

.. autoclass:: balderhub.waveformmonitor.lib.scenario_features.WaveformMonitorInstrumentChannel
    :members:

Setup Features
==============

Siglent-Devices
---------------

.. autoclass:: balderhub.waveformmonitor.lib.setup_features.siglent.BaseSiglentSDSSeriesInstrument
    :members:

.. autoclass:: balderhub.waveformmonitor.lib.setup_features.siglent.SiglentSDS814xHDInstrument
    :members:

Channel Selection Features
--------------------------

.. autoclass:: balderhub.waveformmonitor.lib.setup_features.DirtyWaveformMonitorChannel
    :members:

.. autoclass:: balderhub.waveformmonitor.lib.setup_features.WaveformMonitorInstrumentChannel1
    :members:

.. autoclass:: balderhub.waveformmonitor.lib.setup_features.WaveformMonitorInstrumentChannel2
    :members:
